import CustomElementRegistry from './html-element/CustomElementRegistry';
import Document from './nodes/Document';
import Node from './nodes/Node';
import TextNode from './nodes/TextNode';
import CommentNode from './nodes/CommentNode';
import ShadowRoot from './nodes/ShadowRoot';
import Element from './nodes/Element';
import HTMLElement from './nodes/HTMLElement';
import HTMLTemplateElement from './nodes/HTMLTemplateElement';
import DocumentFragment from './nodes/DocumentFragment';
import TreeWalker from './tree-walker/TreeWalker';
import Event from './event/Event';
import CustomEvent from './event/CustomEvent';
import EventTarget from './event/EventTarget';
import URL from './location/URL';
import Location from './location/Location';
import MutationObserver from './mutation-observer/MutationObserver';
import ShadowRootRenderOptions from './shadow-root/ShadowRootRenderOptions';
/**
 * Handles the Window.
 */
export default class Window extends EventTarget {
    Node: typeof Node;
    TextNode: typeof TextNode;
    CommentNode: typeof CommentNode;
    ShadowRoot: typeof ShadowRoot;
    HTMLElement: typeof HTMLElement;
    HTMLTemplateElement: typeof HTMLTemplateElement;
    Element: typeof Element;
    DocumentFragment: typeof DocumentFragment;
    NodeFilter: {
        FILTER_ACCEPT: number;
        FILTER_REJECT: number;
        FILTER_SKIP: number;
        SHOW_ALL: number;
        SHOW_ATTRIBUTE: number;
        SHOW_CDATA_SECTION: number;
        SHOW_COMMENT: number;
        SHOW_DOCUMENT: number;
        SHOW_DOCUMENT_FRAGMENT: number;
        SHOW_DOCUMENT_TYPE: number;
        SHOW_ELEMENT: number;
        SHOW_ENTITY: number;
        SHOW_ENTITY_REFERENCE: number;
        SHOW_NOTATION: number;
        SHOW_PROCESSING_INSTRUCTION: number;
        SHOW_TEXT: number;
    };
    TreeWalker: typeof TreeWalker;
    MutationObserver: typeof MutationObserver;
    Document: typeof Document;
    Event: typeof Event;
    CustomEvent: typeof CustomEvent;
    URL: typeof URL;
    Location: typeof Location;
    CustomElementRegistry: typeof CustomElementRegistry;
    Window: typeof Window;
    Array: ArrayConstructor;
    Object: ObjectConstructor;
    Number: NumberConstructor;
    Symbol: Function;
    Function: FunctionConstructor;
    RegExp: RegExpConstructor;
    Date: DateConstructor;
    JSON: JSON;
    Promise: Function;
    Error: ErrorConstructor;
    document: Document;
    customElements: CustomElementRegistry;
    location: Location;
    navigator: {
        userAgent: string;
    };
    self: this;
    console: Console;
    shadowRootRenderOptions: ShadowRootRenderOptions;
    /**
     * Constructor.
     */
    constructor();
    /**
     * Returns an object containing the values of all CSS properties of an element.
     *
     * @note This method has not been implemented. It is just here for compatibility.
     * @return {object} Empty object.
     */
    getComputedStyle(): {};
    /**
     * Scrolls to a particular set of coordinates in the document.
     *
     * @note This method has not been implemented. It is just here for compatibility.
     */
    scrollTo(): void;
    /**
     * Disposes the window.
     */
    dispose(): void;
}
